> ![MikroE](http://www.mikroe.com/img/designs/beta/logo_small.png)
> #Compass 2 Click#
> ##By [MikroElektronika](http://www.mikroe.com)
---

## Installation
Use the package manager to install the library for your architecture.

###Example on FT90
```
#include <stdint.h>

/*      Functions
 ****************************/

#include <stdint.h>
#include "compass2_hw.h"

sbit COMPASS2_CS at GPIO_PIN28_bit;
sbit COMPASS2_RST at GPIO_PIN1_bit;


void system_setup( bus_mode_t mode, uint8_t addr );

float mRes;                  // scale resolutions per LSB for the sensors
uint8_t asax, asay, asaz;
float adjusted_ASAX, adjusted_ASAY, adjusted_ASAZ;
float heading, adjusted_MX, adjusted_MY, adjusted_MZ, magbias[3];
int16_t mx, my, mz;
char text[20] = { 0 };

void main()
{
  // Local Declarations
        uint8_t address = 0x0F;
        bus_mode_t my_mode = I2C;
        float heading = 0;
        char uart_text[5] = { 0 };

        system_setup( my_mode, address );

        while(1)
        {
            compass2_get_all_values( &mx, &my, &mz );
            heading = compass2_get_compass_heading( mx, my, mz );

            if( heading < 0 )
                heading += 360;

            UART1_Write_Text( "Heading: " );
            FloatToStr( heading, text );
            UART1_Write_Text( text );
            UART1_Write_Text( " Direction: " );

            if( heading >= 330 || heading <= 30 )
            {
                uart_text[0] = 'N';
                uart_text[1] = '\n';
            }
            else if( heading >= 300 && heading <= 330 )
            {
                uart_text[0] = 'N';
                uart_text[1] = 'W';
                uart_text[2] = '\n';
            }
            else if( heading >= 240 && heading <= 300)
            {
                uart_text[0] = 'W';
                uart_text[1] = '\n';
            }
            else if( heading >= 210 && heading <= 240 )
            {
                uart_text[0] = 'S';
                uart_text[1] = 'W';
                uart_text[2] = '\n';
            }
            else if( heading <= 210 && heading >= 150 )
            {
                uart_text[0] = 'S';
                uart_text[1] = '\n';
            }
            else if( heading <= 150 && heading >= 120 )
            {
                uart_text[0] = 'S';
                uart_text[1] = 'E';
                uart_text[2] = '\n';
            }
            else if( heading <= 120 && heading >= 60 )
            {
                uart_text[0] = 'E';
                uart_text[1] = '\n';
            }
            else if( heading <= 60 && heading >= 30 )
            {
                uart_text[0] = 'N';
                uart_text[1] = 'E';
                uart_text[2] = '\n';
            }

            UART1_Write_Text( uart_text );
            UART1_Write_Text( "\r\n" );

            Delay_ms(100);
        }

}

void system_setup( bus_mode_t mode, uint8_t addr )
{


             //GPIOs
         GPIO_Digital_Output(&GPIO_PORT_24_31, _GPIO_PINMASK_4 );
         GPIO_Digital_Output(&GPIO_PORT_00_07, _GPIO_PINMASK_1 );
         
         //Toggle Reset Pin
         COMPASS2_RST = 0;
         Delay_ms(50);
         COMPASS2_RST = 1;
         Delay_ms(200);


        // UART
        UART1_Init( 9600 );
        UART1_Write_Text( "UART Initialized\r\n" );

        // I2C
        I2CM1_Init( _I2CM_SPEED_MODE_STANDARD, _I2CM_SWAP_DISABLE );
        Delay_ms(200);
        UART1_Write_Text( "I2C Initialized\r\n" );


        // Compass 2
        UART1_Write_Text( "Getting Device ID..." );
        compass2_hw_init( addr, mode );
        UART1_Write_Text( "Compass Initialized\r\n" );

        // Compass 2 setup
        mRes = compass2_set_scale_factor( RES_16 );
        magbias[0] = +470;
        magbias[1] = +120;
        magbias[2] = +125;

        compass2_get_self_test( &mx, &my, &mz );
        UART1_Write_Text( "x y z Values: " );
        LongWordToStr( mx, text );
        UART1_Write_Text( text );
        UART1_Write_Text( "\t" );
        LongWordToStr( my, text );
        UART1_Write_Text( text );
        UART1_Write_Text( "\t" );
        LongWordToStr( mz, text );
        UART1_Write_Text( text );
        UART1_Write_Text( "\r\n" );

        compass2_get_adjustment( &asax, &asay, &asaz );
        adjusted_ASAX = ( (float)asax - 128 ) / 256 + 1;
        adjusted_ASAY = ( (float)asay - 128 ) / 256 + 1;
        adjusted_ASAZ = ( (float)asaz - 128 ) / 256 + 1;

        compass2_set_mode( MODE_CONT_1 );
        compass2_set_scale_factor( RES_16 );

        UART1_Write_Text( "Compass2 Setup Completed..\r\n" );
}
```