#include <stdint.h>
#include "compass2_hw.h"

sbit COMPASS2_CS at GPIO_PIN28_bit;
sbit COMPASS2_RST at GPIO_PIN1_bit;


void system_setup( bus_mode_t mode, uint8_t addr );

float mRes;                  // scale resolutions per LSB for the sensors
uint8_t asax, asay, asaz;
float adjusted_ASAX, adjusted_ASAY, adjusted_ASAZ;
float heading, adjusted_MX, adjusted_MY, adjusted_MZ, magbias[3];
int16_t mx, my, mz;
char text[20] = { 0 };

void main()
{
        // Local Declarations
        uint8_t address = 0x0F;
        bus_mode_t my_mode = I2C;
        float heading = 0;
        char uart_text[5] = { 0 };

        system_setup( my_mode, address );

                UART1_Write_Text( "\r\n----Please Hold The Click Level----\r\n\r\n\r\n" );
                Delay_ms(2000);

        while (1)
        {
             while( !compass2_get_data_ready() );   //Wait for data to be ready

                        compass2_get_all_values( &mx, &my, &mz );               //Get x,y,z values for heading
            heading = compass2_get_compass_heading( mx, my, mz );   //Get heading

                        FloatToStr( heading, uart_text );
                        UART1_Write_Text( "Heading : " );
                        UART1_Write_Text( uart_text );
                        UART1_Write_Text( "\r\n" );
        }

}

void system_setup( bus_mode_t mode, uint8_t addr )
{

         uint8_t my_address = 0;
             //GPIOs
         GPIO_Digital_Output(&GPIO_PORT_24_31, _GPIO_PINMASK_4 );
         GPIO_Digital_Output(&GPIO_PORT_00_07, _GPIO_PINMASK_1 );
         
         //Toggle Reset Pin
         COMPASS2_RST = 0;
         Delay_ms(50);
         COMPASS2_RST = 1;
         Delay_ms(200);


        // UART
        UART1_Init( 9600 );
        UART1_Write_Text( "UART Initialized\r\n" );

        // I2C
        I2CM1_Init( _I2CM_SPEED_MODE_STANDARD, _I2CM_SWAP_DISABLE );
        Delay_ms(200);
        UART1_Write_Text( "I2C Initialized\r\n" );


        // Compass 2
        UART1_Write_Text( "Getting Device ID..." );
        compass2_hw_init( addr, mode );
        UART1_Write_Text( "Compass Initialized\r\n" );

        // Device Address
        my_address = compass2_get_device_id();
        IntToStr( my_address, text );
        UART1_Write_Text( text );
        UART1_Write_Text( "\r\n" );

        // Continuous Measurment Mode / Output Res
        compass2_set_output_res( RES_16 );
        compass2_set_mode( MODE_CONT_2 );

        UART1_Write_Text( "Compass2 Setup Completed..\r\n" );
}